# Sugar Rush

Additions to python-sat (https://github.com/pysathq/pysat)
to automate some things. Extra features:
- Convert disjunction of CNFs to an equivalent CNF
- Automatic optimization using ITotalizer (binary search)